pub struct PyAttributeCertificate { /* private fields */ }Expand description
X.509 Attribute Certificate v2 (RFC 5755).
An Attribute Certificate (AC) binds a set of attributes (roles, clearances, service-authentication information) to a holder identified by reference to their Public Key Certificate (PKC), without requiring re-issuance of the PKC.
import synta.ac as ac
acer = ac.AttributeCertificate.from_der(open("attr.ac", "rb").read())
print(acer.serial_number.hex())
print(acer.not_before, "–", acer.not_after)
print(acer.signature_algorithm_oid)Trait Implementations
Sourceimpl<'py> IntoPyObject<'py> for PyAttributeCertificate
impl<'py> IntoPyObject<'py> for PyAttributeCertificate
Sourcetype Target = PyAttributeCertificate
type Target = PyAttributeCertificate
The Python output type
Sourcetype Output = Bound<'py, <PyAttributeCertificate as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyAttributeCertificate as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyAttributeCertificate
impl PyClass for PyAttributeCertificate
Sourceimpl PyClassImpl for PyAttributeCertificate
impl PyClassImpl for PyAttributeCertificate
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// X.509 Attribute Certificate v2 (RFC 5755).
///
/// An Attribute Certificate (AC) binds a set of attributes (roles, clearances,
/// service-authentication information) to a holder identified by reference to
/// their Public Key Certificate (PKC), without requiring re-issuance of the PKC.
///
/// ```python,ignore
/// import synta.ac as ac
/// acer = ac.AttributeCertificate.from_der(open("attr.ac", "rb").read())
/// print(acer.serial_number.hex())
/// print(acer.not_before, "–", acer.not_after)
/// print(acer.signature_algorithm_oid)
/// ```
const RAW_DOC: &'static CStr = /// X.509 Attribute Certificate v2 (RFC 5755). /// /// An Attribute Certificate (AC) binds a set of attributes (roles, clearances, /// service-authentication information) to a holder identified by reference to /// their Public Key Certificate (PKC), without requiring re-issuance of the PKC. /// /// ```python,ignore /// import synta.ac as ac /// acer = ac.AttributeCertificate.from_der(open("attr.ac", "rb").read()) /// print(acer.serial_number.hex()) /// print(acer.not_before, "–", acer.not_after) /// print(acer.signature_algorithm_oid) /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyAttributeCertificate>
type ThreadChecker = SendablePyClass<PyAttributeCertificate>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyMethods<PyAttributeCertificate> for PyClassImplCollector<PyAttributeCertificate>
impl PyMethods<PyAttributeCertificate> for PyClassImplCollector<PyAttributeCertificate>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyAttributeCertificate
impl PyTypeInfo for PyAttributeCertificate
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
impl DerefToPyAny for PyAttributeCertificate
impl ExtractPyClassWithClone for PyAttributeCertificate