pub struct PyAttributeCertificateBuilder { /* private fields */ }Expand description
Builder for RFC 5755 Attribute Certificate TBS encoding.
Use the fluent setter methods to configure the certificate, then call
:meth:build to obtain the DER-encoded AttributeCertificateInfo
(TBS) SEQUENCE.
import synta.ac as ac
tbs_der = (
ac.AttributeCertificateBuilder()
.serial_number(42)
.not_before("20240101120000Z")
.not_after("20250101120000Z")
.issuer_rfc822("ca@example.com")
.holder_entity_name_rfc822("user@example.com")
.build()
)Trait Implementations
impl DerefToPyAny for PyAttributeCertificateBuilder
impl ExtractPyClassWithClone for PyAttributeCertificateBuilder
Sourceimpl<'py> IntoPyObject<'py> for PyAttributeCertificateBuilder
impl<'py> IntoPyObject<'py> for PyAttributeCertificateBuilder
Sourcetype Target = PyAttributeCertificateBuilder
type Target = PyAttributeCertificateBuilder
The Python output type
Sourcetype Output = Bound<'py, <PyAttributeCertificateBuilder as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyAttributeCertificateBuilder as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClassImpl for PyAttributeCertificateBuilder
impl PyClassImpl for PyAttributeCertificateBuilder
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Builder for RFC 5755 Attribute Certificate TBS encoding.
///
/// Use the fluent setter methods to configure the certificate, then call
/// :meth:`build` to obtain the DER-encoded ``AttributeCertificateInfo``
/// (TBS) SEQUENCE.
///
/// ```python,ignore
/// import synta.ac as ac
///
/// tbs_der = (
/// ac.AttributeCertificateBuilder()
/// .serial_number(42)
/// .not_before("20240101120000Z")
/// .not_after("20250101120000Z")
/// .issuer_rfc822("ca@example.com")
/// .holder_entity_name_rfc822("user@example.com")
/// .build()
/// )
/// ```
const RAW_DOC: &'static CStr = /// Builder for RFC 5755 Attribute Certificate TBS encoding. /// /// Use the fluent setter methods to configure the certificate, then call /// :meth:`build` to obtain the DER-encoded ``AttributeCertificateInfo`` /// (TBS) SEQUENCE. /// /// ```python,ignore /// import synta.ac as ac /// /// tbs_der = ( /// ac.AttributeCertificateBuilder() /// .serial_number(42) /// .not_before("20240101120000Z") /// .not_after("20250101120000Z") /// .issuer_rfc822("ca@example.com") /// .holder_entity_name_rfc822("user@example.com") /// .build() /// ) /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyAttributeCertificateBuilder>
type ThreadChecker = SendablePyClass<PyAttributeCertificateBuilder>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for PyAttributeCertificateBuilder
impl PyClassNewTextSignature for PyAttributeCertificateBuilder
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<PyAttributeCertificateBuilder> for PyClassImplCollector<PyAttributeCertificateBuilder>
impl PyMethods<PyAttributeCertificateBuilder> for PyClassImplCollector<PyAttributeCertificateBuilder>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyAttributeCertificateBuilder
impl PyTypeInfo for PyAttributeCertificateBuilder
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.