pub struct PyAuthenticationContextsBuilder { /* private fields */ }Expand description
Python-facing wrapper for
synta_certificate::AuthenticationContextsBuilder.
Builds a DER-encoded AuthenticationContexts SEQUENCE OF (RFC 7773 /
ACE-88).
Each entry is an AuthenticationContext with a mandatory
contextType UTF8String and an optional contextInfo UTF8String.
At least one entry must be added before calling :meth:build.
The resulting DER goes inside the OCTET STRING wrapper of an X.509
Extension SEQUENCE for OID 1.2.752.201.5.1
(id-ce-authContext).
Example::
import synta
extn_der = (
synta.AuthenticationContextsBuilder()
.add("urn:id:skatteverket:2:1.0", None)
.add(
"urn:id:skatteverket:1:1.0",
"https://www.skatteverket.se/ac/context",
)
.build()
)Trait Implementations
impl DerefToPyAny for PyAuthenticationContextsBuilder
impl ExtractPyClassWithClone for PyAuthenticationContextsBuilder
Sourceimpl<'py> IntoPyObject<'py> for PyAuthenticationContextsBuilder
impl<'py> IntoPyObject<'py> for PyAuthenticationContextsBuilder
Sourcetype Target = PyAuthenticationContextsBuilder
type Target = PyAuthenticationContextsBuilder
The Python output type
Sourcetype Output = Bound<'py, <PyAuthenticationContextsBuilder as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyAuthenticationContextsBuilder as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClassImpl for PyAuthenticationContextsBuilder
impl PyClassImpl for PyAuthenticationContextsBuilder
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Python-facing wrapper for
/// [`synta_certificate::AuthenticationContextsBuilder`].
///
/// Builds a DER-encoded ``AuthenticationContexts`` SEQUENCE OF (RFC 7773 /
/// ACE-88).
///
/// Each entry is an ``AuthenticationContext`` with a mandatory
/// ``contextType`` UTF8String and an optional ``contextInfo`` UTF8String.
/// At least one entry must be added before calling :meth:`build`.
///
/// The resulting DER goes inside the OCTET STRING wrapper of an X.509
/// ``Extension`` SEQUENCE for OID ``1.2.752.201.5.1``
/// (``id-ce-authContext``).
///
/// Example::
///
/// import synta
///
/// extn_der = (
/// synta.AuthenticationContextsBuilder()
/// .add("urn:id:skatteverket:2:1.0", None)
/// .add(
/// "urn:id:skatteverket:1:1.0",
/// "https://www.skatteverket.se/ac/context",
/// )
/// .build()
/// )
const RAW_DOC: &'static CStr = /// Python-facing wrapper for /// [`synta_certificate::AuthenticationContextsBuilder`]. /// /// Builds a DER-encoded ``AuthenticationContexts`` SEQUENCE OF (RFC 7773 / /// ACE-88). /// /// Each entry is an ``AuthenticationContext`` with a mandatory /// ``contextType`` UTF8String and an optional ``contextInfo`` UTF8String. /// At least one entry must be added before calling :meth:`build`. /// /// The resulting DER goes inside the OCTET STRING wrapper of an X.509 /// ``Extension`` SEQUENCE for OID ``1.2.752.201.5.1`` /// (``id-ce-authContext``). /// /// Example:: /// /// import synta /// /// extn_der = ( /// synta.AuthenticationContextsBuilder() /// .add("urn:id:skatteverket:2:1.0", None) /// .add( /// "urn:id:skatteverket:1:1.0", /// "https://www.skatteverket.se/ac/context", /// ) /// .build() /// )
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyAuthenticationContextsBuilder>
type ThreadChecker = SendablePyClass<PyAuthenticationContextsBuilder>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for PyAuthenticationContextsBuilder
impl PyClassNewTextSignature for PyAuthenticationContextsBuilder
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<PyAuthenticationContextsBuilder> for PyClassImplCollector<PyAuthenticationContextsBuilder>
impl PyMethods<PyAuthenticationContextsBuilder> for PyClassImplCollector<PyAuthenticationContextsBuilder>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyAuthenticationContextsBuilder
impl PyTypeInfo for PyAuthenticationContextsBuilder
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.