pub struct PyCMPMessageBuilder { /* private fields */ }Expand description
Fluent builder for a CMP PKIMessage (RFC 9810 / RFC 4210).
Set sender, recipient, optional nonces, and a body payload, then call
:meth:build to produce a :class:CMPMessage.
import synta.cmp as cmp
msg = (
cmp.CMPMessageBuilder()
.sender_rfc822("ca@example.com")
.recipient_directory_name(subject_der)
.transaction_id(b"\x01\x02\x03\x04")
.body_pkiconf()
.build()
)
print(msg.pvno, msg.body_type)Trait Implementations
impl DerefToPyAny for PyCMPMessageBuilder
impl ExtractPyClassWithClone for PyCMPMessageBuilder
Sourceimpl<'py> IntoPyObject<'py> for PyCMPMessageBuilder
impl<'py> IntoPyObject<'py> for PyCMPMessageBuilder
Sourcetype Target = PyCMPMessageBuilder
type Target = PyCMPMessageBuilder
The Python output type
Sourcetype Output = Bound<'py, <PyCMPMessageBuilder as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyCMPMessageBuilder as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyCMPMessageBuilder
impl PyClass for PyCMPMessageBuilder
Sourceimpl PyClassImpl for PyCMPMessageBuilder
impl PyClassImpl for PyCMPMessageBuilder
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Fluent builder for a CMP ``PKIMessage`` (RFC 9810 / RFC 4210).
///
/// Set sender, recipient, optional nonces, and a body payload, then call
/// :meth:`build` to produce a :class:`CMPMessage`.
///
/// ```python,ignore
/// import synta.cmp as cmp
///
/// msg = (
/// cmp.CMPMessageBuilder()
/// .sender_rfc822("ca@example.com")
/// .recipient_directory_name(subject_der)
/// .transaction_id(b"\x01\x02\x03\x04")
/// .body_pkiconf()
/// .build()
/// )
/// print(msg.pvno, msg.body_type)
/// ```
const RAW_DOC: &'static CStr = /// Fluent builder for a CMP ``PKIMessage`` (RFC 9810 / RFC 4210). /// /// Set sender, recipient, optional nonces, and a body payload, then call /// :meth:`build` to produce a :class:`CMPMessage`. /// /// ```python,ignore /// import synta.cmp as cmp /// /// msg = ( /// cmp.CMPMessageBuilder() /// .sender_rfc822("ca@example.com") /// .recipient_directory_name(subject_der) /// .transaction_id(b"\x01\x02\x03\x04") /// .body_pkiconf() /// .build() /// ) /// print(msg.pvno, msg.body_type) /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyCMPMessageBuilder>
type ThreadChecker = SendablePyClass<PyCMPMessageBuilder>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for PyCMPMessageBuilder
impl PyClassNewTextSignature for PyCMPMessageBuilder
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<PyCMPMessageBuilder> for PyClassImplCollector<PyCMPMessageBuilder>
impl PyMethods<PyCMPMessageBuilder> for PyClassImplCollector<PyCMPMessageBuilder>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyCMPMessageBuilder
impl PyTypeInfo for PyCMPMessageBuilder
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.