pub struct PyCsrBuilder { /* private fields */ }Expand description
Builder for PKCS #10 Certificate Signing Requests.
The subject Name and SubjectPublicKeyInfo bytes are stored as-is and spliced
verbatim into the CertificationRequestInfo DER at signing time — no
re-parse or re-encode.
Each setter method returns the same builder object, so calls can be
chained with .:
import synta
csr = (
synta.CsrBuilder()
.subject_name(cert.subject_raw_der)
.public_key(key.public_key())
.add_extension("2.5.29.17", False, san_der)
.sign(key, "sha256")
)Trait Implementations
impl DerefToPyAny for PyCsrBuilder
impl ExtractPyClassWithClone for PyCsrBuilder
Sourceimpl<'py> IntoPyObject<'py> for PyCsrBuilder
impl<'py> IntoPyObject<'py> for PyCsrBuilder
Sourcetype Target = PyCsrBuilder
type Target = PyCsrBuilder
The Python output type
Sourcetype Output = Bound<'py, <PyCsrBuilder as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyCsrBuilder as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyCsrBuilder
impl PyClass for PyCsrBuilder
Sourceimpl PyClassImpl for PyCsrBuilder
impl PyClassImpl for PyCsrBuilder
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Builder for PKCS #10 Certificate Signing Requests.
///
/// The subject Name and SubjectPublicKeyInfo bytes are stored as-is and spliced
/// verbatim into the ``CertificationRequestInfo`` DER at signing time — no
/// re-parse or re-encode.
///
/// Each setter method returns the **same** builder object, so calls can be
/// chained with ``.``:
///
/// ```python,ignore
/// import synta
///
/// csr = (
/// synta.CsrBuilder()
/// .subject_name(cert.subject_raw_der)
/// .public_key(key.public_key())
/// .add_extension("2.5.29.17", False, san_der)
/// .sign(key, "sha256")
/// )
/// ```
const RAW_DOC: &'static CStr = /// Builder for PKCS #10 Certificate Signing Requests. /// /// The subject Name and SubjectPublicKeyInfo bytes are stored as-is and spliced /// verbatim into the ``CertificationRequestInfo`` DER at signing time — no /// re-parse or re-encode. /// /// Each setter method returns the **same** builder object, so calls can be /// chained with ``.``: /// /// ```python,ignore /// import synta /// /// csr = ( /// synta.CsrBuilder() /// .subject_name(cert.subject_raw_der) /// .public_key(key.public_key()) /// .add_extension("2.5.29.17", False, san_der) /// .sign(key, "sha256") /// ) /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyCsrBuilder>
type ThreadChecker = SendablePyClass<PyCsrBuilder>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for PyCsrBuilder
impl PyClassNewTextSignature for PyCsrBuilder
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<PyCsrBuilder> for PyClassImplCollector<PyCsrBuilder>
impl PyMethods<PyCsrBuilder> for PyClassImplCollector<PyCsrBuilder>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyCsrBuilder
impl PyTypeInfo for PyCsrBuilder
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.