PyMlDsaPublicKey

Struct PyMlDsaPublicKey 

pub struct PyMlDsaPublicKey { /* private fields */ }
A validated ML-DSA public key (RFC 9881 / FIPS 204).

ML-DSA public keys are raw byte strings carried in SubjectPublicKeyInfo.subjectPublicKey (as BIT STRING value bytes, with the unused-bits prefix stripped). The expected sizes are:

  • ML_DSA_44 — 1312 bytes
  • ML_DSA_65 — 1952 bytes
  • ML_DSA_87 — 2592 bytes

Use :meth:from_bytes with the algorithm OID from SubjectPublicKeyInfo.algorithm to validate and wrap the raw key bytes:

oid = cert.subject_public_key_algorithm
raw = cert.subject_public_key
pub_key = synta.MlDsaPublicKey.from_bytes(oid, raw)