PyLogotypeExtnBuilder

Struct PyLogotypeExtnBuilder 

pub struct PyLogotypeExtnBuilder { /* private fields */ }
Python-facing wrapper for synta_certificate::LogotypeExtnBuilder.

Builds a DER-encoded LogotypeExtn SEQUENCE (RFC 9399).

The extension value goes inside the OCTET STRING wrapper of an X.509 Extension SEQUENCE for OID 1.3.6.1.5.5.7.1.12.

At least one of communityLogos, issuerLogo, subjectLogo, or otherLogos must be set before calling :meth:build.

Each logo is described by four parameters passed as keyword arguments or positional values to the setter methods:

  • media_type — MIME type string, e.g. "image/png"
  • hash_alg_oid — hash algorithm OID as a list of arc integers, e.g. list(synta.oids.SHA256.components())
  • hash_value — raw hash bytes of the logotype object
  • uri — URI from which the logotype can be retrieved

Example::

import hashlib, synta

img_hash = hashlib.sha256(open("logo.png", "rb").read()).digest()
sha256_comps = list(synta.oids.SHA256.components())

extn_der = (
    synta.LogotypeExtnBuilder()
    .subject_logo_direct(
        media_type="image/png",
        hash_alg_oid=sha256_comps,
        hash_value=img_hash,
        uri="https://www.example.com/logo.png",
    )
    .build()
)