pub struct PyAlgorithmIdentifier { /* private fields */ }Expand description
An X.509 AlgorithmIdentifier SEQUENCE (RFC 5280 4.1.1.2).
Wraps an algorithm OID and optional parameters as a pre-encoded DER
SEQUENCE. Use :meth:to_der to obtain bytes ready for passing to builder
APIs such as :meth:~synta.CertificateListBuilder.signature_algorithm.
Two constructors handle the two conventions used in practice:
- :meth:
from_oid— RSA-family algorithms; encodesSEQUENCE { oid, NULL } - :meth:
from_oid_no_params— ECDSA/EdDSA; encodesSEQUENCE { oid }
import synta
alg = synta.AlgorithmIdentifier.from_oid(synta.oids.SHA256_WITH_RSA)
crl_builder.signature_algorithm(alg.to_der())Trait Implementations
impl DerefToPyAny for PyAlgorithmIdentifier
impl ExtractPyClassWithClone for PyAlgorithmIdentifier
Sourceimpl<'py> IntoPyObject<'py> for PyAlgorithmIdentifier
impl<'py> IntoPyObject<'py> for PyAlgorithmIdentifier
Sourcetype Target = PyAlgorithmIdentifier
type Target = PyAlgorithmIdentifier
The Python output type
Sourcetype Output = Bound<'py, <PyAlgorithmIdentifier as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyAlgorithmIdentifier as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyAlgorithmIdentifier
impl PyClass for PyAlgorithmIdentifier
Sourceimpl PyClassImpl for PyAlgorithmIdentifier
impl PyClassImpl for PyAlgorithmIdentifier
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// An X.509 ``AlgorithmIdentifier`` SEQUENCE (RFC 5280 4.1.1.2).
///
/// Wraps an algorithm OID and optional parameters as a pre-encoded DER
/// SEQUENCE. Use :meth:`to_der` to obtain bytes ready for passing to builder
/// APIs such as :meth:`~synta.CertificateListBuilder.signature_algorithm`.
///
/// Two constructors handle the two conventions used in practice:
///
/// * :meth:`from_oid` — RSA-family algorithms; encodes ``SEQUENCE { oid, NULL }``
/// * :meth:`from_oid_no_params` — ECDSA/EdDSA; encodes ``SEQUENCE { oid }``
///
/// ```python,ignore
/// import synta
/// alg = synta.AlgorithmIdentifier.from_oid(synta.oids.SHA256_WITH_RSA)
/// crl_builder.signature_algorithm(alg.to_der())
/// ```
const RAW_DOC: &'static CStr = /// An X.509 ``AlgorithmIdentifier`` SEQUENCE (RFC 5280 4.1.1.2). /// /// Wraps an algorithm OID and optional parameters as a pre-encoded DER /// SEQUENCE. Use :meth:`to_der` to obtain bytes ready for passing to builder /// APIs such as :meth:`~synta.CertificateListBuilder.signature_algorithm`. /// /// Two constructors handle the two conventions used in practice: /// /// * :meth:`from_oid` — RSA-family algorithms; encodes ``SEQUENCE { oid, NULL }`` /// * :meth:`from_oid_no_params` — ECDSA/EdDSA; encodes ``SEQUENCE { oid }`` /// /// ```python,ignore /// import synta /// alg = synta.AlgorithmIdentifier.from_oid(synta.oids.SHA256_WITH_RSA) /// crl_builder.signature_algorithm(alg.to_der()) /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyAlgorithmIdentifier>
type ThreadChecker = SendablePyClass<PyAlgorithmIdentifier>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyMethods<PyAlgorithmIdentifier> for PyClassImplCollector<PyAlgorithmIdentifier>
impl PyMethods<PyAlgorithmIdentifier> for PyClassImplCollector<PyAlgorithmIdentifier>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyAlgorithmIdentifier
impl PyTypeInfo for PyAlgorithmIdentifier
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.