pub struct PyDssParms { /* private fields */ }Expand description
DSA domain parameters (RFC 3279 2.3.2).
Carries the prime modulus p, prime divisor q, and generator g
parameters for a DSA public key. Decoded from the parameters field
of an AlgorithmIdentifier whose OID is id-dsa.
import synta.pkixalgs as pa
parms = pa.DssParms.from_der(alg_id_params_der)
print(len(parms.p)) # byte length of pTrait Implementations
Sourceimpl<'py> IntoPyObject<'py> for PyDssParms
impl<'py> IntoPyObject<'py> for PyDssParms
Sourcetype Target = PyDssParms
type Target = PyDssParms
The Python output type
Sourcetype Output = Bound<'py, <PyDssParms as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyDssParms as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClassImpl for PyDssParms
impl PyClassImpl for PyDssParms
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// DSA domain parameters (RFC 3279 2.3.2).
///
/// Carries the prime modulus ``p``, prime divisor ``q``, and generator ``g``
/// parameters for a DSA public key. Decoded from the ``parameters`` field
/// of an ``AlgorithmIdentifier`` whose OID is ``id-dsa``.
///
/// ```python,ignore
/// import synta.pkixalgs as pa
/// parms = pa.DssParms.from_der(alg_id_params_der)
/// print(len(parms.p)) # byte length of p
/// ```
const RAW_DOC: &'static CStr = /// DSA domain parameters (RFC 3279 2.3.2). /// /// Carries the prime modulus ``p``, prime divisor ``q``, and generator ``g`` /// parameters for a DSA public key. Decoded from the ``parameters`` field /// of an ``AlgorithmIdentifier`` whose OID is ``id-dsa``. /// /// ```python,ignore /// import synta.pkixalgs as pa /// parms = pa.DssParms.from_der(alg_id_params_der) /// print(len(parms.p)) # byte length of p /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyDssParms>
type ThreadChecker = SendablePyClass<PyDssParms>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyMethods<PyDssParms> for PyClassImplCollector<PyDssParms>
impl PyMethods<PyDssParms> for PyClassImplCollector<PyDssParms>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyDssParms
impl PyTypeInfo for PyDssParms
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
impl DerefToPyAny for PyDssParms
impl ExtractPyClassWithClone for PyDssParms