pub struct PyIssuerAndSerialNumber { /* private fields */ }Expand description
CMS IssuerAndSerialNumber (RFC 5652 10.2.4) accessible from Python.
Identifies a recipient or signer by the issuer distinguished name and
certificate serial number of their certificate. Used as one alternative
of the RecipientIdentifier CHOICE inside :class:KEMRecipientInfo.
ias = IssuerAndSerialNumber.from_der(raw)
print(ias.issuer) # "CN=My CA,O=Example,C=US"
print(ias.serial_number) # 12345678Trait Implementations
Sourceimpl<'py> IntoPyObject<'py> for PyIssuerAndSerialNumber
impl<'py> IntoPyObject<'py> for PyIssuerAndSerialNumber
Sourcetype Target = PyIssuerAndSerialNumber
type Target = PyIssuerAndSerialNumber
The Python output type
Sourcetype Output = Bound<'py, <PyIssuerAndSerialNumber as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyIssuerAndSerialNumber as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyIssuerAndSerialNumber
impl PyClass for PyIssuerAndSerialNumber
Sourceimpl PyClassImpl for PyIssuerAndSerialNumber
impl PyClassImpl for PyIssuerAndSerialNumber
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// CMS IssuerAndSerialNumber (RFC 5652 10.2.4) accessible from Python.
///
/// Identifies a recipient or signer by the issuer distinguished name and
/// certificate serial number of their certificate. Used as one alternative
/// of the ``RecipientIdentifier`` CHOICE inside :class:`KEMRecipientInfo`.
///
/// ```python,ignore
/// ias = IssuerAndSerialNumber.from_der(raw)
/// print(ias.issuer) # "CN=My CA,O=Example,C=US"
/// print(ias.serial_number) # 12345678
/// ```
const RAW_DOC: &'static CStr = /// CMS IssuerAndSerialNumber (RFC 5652 10.2.4) accessible from Python. /// /// Identifies a recipient or signer by the issuer distinguished name and /// certificate serial number of their certificate. Used as one alternative /// of the ``RecipientIdentifier`` CHOICE inside :class:`KEMRecipientInfo`. /// /// ```python,ignore /// ias = IssuerAndSerialNumber.from_der(raw) /// print(ias.issuer) # "CN=My CA,O=Example,C=US" /// print(ias.serial_number) # 12345678 /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyIssuerAndSerialNumber>
type ThreadChecker = SendablePyClass<PyIssuerAndSerialNumber>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyMethods<PyIssuerAndSerialNumber> for PyClassImplCollector<PyIssuerAndSerialNumber>
impl PyMethods<PyIssuerAndSerialNumber> for PyClassImplCollector<PyIssuerAndSerialNumber>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyIssuerAndSerialNumber
impl PyTypeInfo for PyIssuerAndSerialNumber
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
impl DerefToPyAny for PyIssuerAndSerialNumber
impl ExtractPyClassWithClone for PyIssuerAndSerialNumber