pub struct PySignedData { /* private fields */ }Expand description
CMS SignedData (RFC 5652 5) accessible from Python.
Obtained by parsing the inner content of a :class:ContentInfo whose
content_type_oid equals :data:~synta.cms.ID_SIGNED_DATA. Strip the
[0] EXPLICIT wrapper from ci.content before calling
:meth:from_der.
ci = ContentInfo.from_der(raw)
sd = SignedData.from_der(ci.content[4:]) # strip [0] EXPLICIT tag+len
print(sd.version)
for si in sd.signer_infos:
print(si.digest_algorithm_oid)Trait Implementations
Sourceimpl<'py> IntoPyObject<'py> for PySignedData
impl<'py> IntoPyObject<'py> for PySignedData
Sourcetype Target = PySignedData
type Target = PySignedData
The Python output type
Sourcetype Output = Bound<'py, <PySignedData as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PySignedData as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PySignedData
impl PyClass for PySignedData
Sourceimpl PyClassImpl for PySignedData
impl PyClassImpl for PySignedData
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// CMS ``SignedData`` (RFC 5652 5) accessible from Python.
///
/// Obtained by parsing the inner content of a :class:`ContentInfo` whose
/// ``content_type_oid`` equals :data:`~synta.cms.ID_SIGNED_DATA`. Strip the
/// ``[0] EXPLICIT`` wrapper from ``ci.content`` before calling
/// :meth:`from_der`.
///
/// ```python,ignore
/// ci = ContentInfo.from_der(raw)
/// sd = SignedData.from_der(ci.content[4:]) # strip [0] EXPLICIT tag+len
/// print(sd.version)
/// for si in sd.signer_infos:
/// print(si.digest_algorithm_oid)
/// ```
const RAW_DOC: &'static CStr = /// CMS ``SignedData`` (RFC 5652 5) accessible from Python. /// /// Obtained by parsing the inner content of a :class:`ContentInfo` whose /// ``content_type_oid`` equals :data:`~synta.cms.ID_SIGNED_DATA`. Strip the /// ``[0] EXPLICIT`` wrapper from ``ci.content`` before calling /// :meth:`from_der`. /// /// ```python,ignore /// ci = ContentInfo.from_der(raw) /// sd = SignedData.from_der(ci.content[4:]) # strip [0] EXPLICIT tag+len /// print(sd.version) /// for si in sd.signer_infos: /// print(si.digest_algorithm_oid) /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PySignedData>
type ThreadChecker = SendablePyClass<PySignedData>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyMethods<PySignedData> for PyClassImplCollector<PySignedData>
impl PyMethods<PySignedData> for PyClassImplCollector<PySignedData>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PySignedData
impl PyTypeInfo for PySignedData
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
impl DerefToPyAny for PySignedData
impl ExtractPyClassWithClone for PySignedData