pub struct PyFernet { /* private fields */ }Expand description
Fernet symmetric authenticated encryption.
Implements the Fernet specification <https://github.com/fernet/spec/blob/master/Spec.md>_
using AES-128-CBC encryption and HMAC-SHA256 authentication. Tokens
produced by this class are byte-for-byte compatible with those produced
by cryptography.fernet.Fernet.
Key format: a URL-safe base64-encoded string of 32 raw bytes, where the first 16 bytes are the signing key and the last 16 bytes are the encryption key.
Token format (before base64url encoding):
- 1 byte: version (
0x80) - 8 bytes: timestamp (big-endian unsigned 64-bit Unix seconds)
- 16 bytes: AES-CBC initialization vector
- N bytes: AES-128-CBC ciphertext (PKCS#7-padded plaintext)
- 32 bytes: HMAC-SHA256 of all preceding bytes
import synta
key = synta.Fernet.generate_key()
fern = synta.Fernet(key)
token = fern.encrypt(b"secret data")
plain = fern.decrypt(token)
assert plain == b"secret data"
# TTL check (seconds):
plain = fern.decrypt(token, ttl=300)Trait Implementations
impl DerefToPyAny for PyFernet
impl ExtractPyClassWithClone for PyFernet
Sourceimpl<'py> IntoPyObject<'py> for PyFernet
impl<'py> IntoPyObject<'py> for PyFernet
Sourcetype Output = Bound<'py, <PyFernet as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyFernet as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClassImpl for PyFernet
impl PyClassImpl for PyFernet
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Fernet symmetric authenticated encryption.
///
/// Implements the `Fernet specification <https://github.com/fernet/spec/blob/master/Spec.md>`_
/// using AES-128-CBC encryption and HMAC-SHA256 authentication. Tokens
/// produced by this class are byte-for-byte compatible with those produced
/// by ``cryptography.fernet.Fernet``.
///
/// **Key format:** a URL-safe base64-encoded string of 32 raw bytes, where
/// the first 16 bytes are the signing key and the last 16 bytes are the
/// encryption key.
///
/// **Token format (before base64url encoding):**
///
/// * 1 byte: version (``0x80``)
/// * 8 bytes: timestamp (big-endian unsigned 64-bit Unix seconds)
/// * 16 bytes: AES-CBC initialization vector
/// * N bytes: AES-128-CBC ciphertext (PKCS#7-padded plaintext)
/// * 32 bytes: HMAC-SHA256 of all preceding bytes
///
/// ```python,ignore
/// import synta
///
/// key = synta.Fernet.generate_key()
/// fern = synta.Fernet(key)
/// token = fern.encrypt(b"secret data")
/// plain = fern.decrypt(token)
/// assert plain == b"secret data"
///
/// # TTL check (seconds):
/// plain = fern.decrypt(token, ttl=300)
/// ```
const RAW_DOC: &'static CStr = /// Fernet symmetric authenticated encryption. /// /// Implements the `Fernet specification <https://github.com/fernet/spec/blob/master/Spec.md>`_ /// using AES-128-CBC encryption and HMAC-SHA256 authentication. Tokens /// produced by this class are byte-for-byte compatible with those produced /// by ``cryptography.fernet.Fernet``. /// /// **Key format:** a URL-safe base64-encoded string of 32 raw bytes, where /// the first 16 bytes are the signing key and the last 16 bytes are the /// encryption key. /// /// **Token format (before base64url encoding):** /// /// * 1 byte: version (``0x80``) /// * 8 bytes: timestamp (big-endian unsigned 64-bit Unix seconds) /// * 16 bytes: AES-CBC initialization vector /// * N bytes: AES-128-CBC ciphertext (PKCS#7-padded plaintext) /// * 32 bytes: HMAC-SHA256 of all preceding bytes /// /// ```python,ignore /// import synta /// /// key = synta.Fernet.generate_key() /// fern = synta.Fernet(key) /// token = fern.encrypt(b"secret data") /// plain = fern.decrypt(token) /// assert plain == b"secret data" /// /// # TTL check (seconds): /// plain = fern.decrypt(token, ttl=300) /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyFernet>
type ThreadChecker = SendablePyClass<PyFernet>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyMethods<PyFernet> for PyClassImplCollector<PyFernet>
impl PyMethods<PyFernet> for PyClassImplCollector<PyFernet>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyFernet
impl PyTypeInfo for PyFernet
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.