pub struct PyAuthorityInformationAccessBuilder { /* private fields */ }Expand description
Fluent builder for an AuthorityInfoAccessSyntax extension value
(OID 1.3.6.1.5.5.7.1.1, Authority Information Access, RFC 5280 4.2.2.1).
Add OCSP and/or CA Issuers URIs with the fluent methods, then call
:meth:build to obtain the DER bytes of the AuthorityInfoAccessSyntax
SEQUENCE — the content that goes inside the OCTET STRING wrapper.
The class is also available as the short alias synta.ext.AIA.
import synta.ext as ext
aia = ext.AIA() \
.ocsp("http://ocsp.example.com") \
.ca_issuers("http://ca.example.com/ca.crt") \
.build()Trait Implementations
impl DerefToPyAny for PyAuthorityInformationAccessBuilder
impl ExtractPyClassWithClone for PyAuthorityInformationAccessBuilder
Sourceimpl<'py> IntoPyObject<'py> for PyAuthorityInformationAccessBuilder
impl<'py> IntoPyObject<'py> for PyAuthorityInformationAccessBuilder
Sourcetype Target = PyAuthorityInformationAccessBuilder
type Target = PyAuthorityInformationAccessBuilder
The Python output type
Sourcetype Output = Bound<'py, <PyAuthorityInformationAccessBuilder as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyAuthorityInformationAccessBuilder as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClassImpl for PyAuthorityInformationAccessBuilder
impl PyClassImpl for PyAuthorityInformationAccessBuilder
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Fluent builder for an ``AuthorityInfoAccessSyntax`` extension value
/// (OID 1.3.6.1.5.5.7.1.1, Authority Information Access, RFC 5280 4.2.2.1).
///
/// Add OCSP and/or CA Issuers URIs with the fluent methods, then call
/// :meth:`build` to obtain the DER bytes of the ``AuthorityInfoAccessSyntax``
/// SEQUENCE — the content that goes inside the OCTET STRING wrapper.
///
/// The class is also available as the short alias ``synta.ext.AIA``.
///
/// ```python,ignore
/// import synta.ext as ext
///
/// aia = ext.AIA() \
/// .ocsp("http://ocsp.example.com") \
/// .ca_issuers("http://ca.example.com/ca.crt") \
/// .build()
/// ```
const RAW_DOC: &'static CStr = /// Fluent builder for an ``AuthorityInfoAccessSyntax`` extension value /// (OID 1.3.6.1.5.5.7.1.1, Authority Information Access, RFC 5280 4.2.2.1). /// /// Add OCSP and/or CA Issuers URIs with the fluent methods, then call /// :meth:`build` to obtain the DER bytes of the ``AuthorityInfoAccessSyntax`` /// SEQUENCE — the content that goes inside the OCTET STRING wrapper. /// /// The class is also available as the short alias ``synta.ext.AIA``. /// /// ```python,ignore /// import synta.ext as ext /// /// aia = ext.AIA() \ /// .ocsp("http://ocsp.example.com") \ /// .ca_issuers("http://ca.example.com/ca.crt") \ /// .build() /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyAuthorityInformationAccessBuilder>
type ThreadChecker = SendablePyClass<PyAuthorityInformationAccessBuilder>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for PyAuthorityInformationAccessBuilder
impl PyClassNewTextSignature for PyAuthorityInformationAccessBuilder
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<PyAuthorityInformationAccessBuilder> for PyClassImplCollector<PyAuthorityInformationAccessBuilder>
impl PyMethods<PyAuthorityInformationAccessBuilder> for PyClassImplCollector<PyAuthorityInformationAccessBuilder>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyAuthorityInformationAccessBuilder
impl PyTypeInfo for PyAuthorityInformationAccessBuilder
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.