pub struct PyCertificatePoliciesBuilder { /* private fields */ }Expand description
Fluent builder for a CertificatePolicies extension value (OID 2.5.29.32,
RFC 5280 4.2.1.4).
Add policy entries with optional CPS URI qualifiers using the fluent methods,
then call :meth:build to obtain the DER bytes of the
CertificatePolicies SEQUENCE OF — the content that goes inside the OCTET
STRING wrapper in the Extension SEQUENCE.
The class is also available as the short alias synta.ext.CP.
import synta.ext as ext
cp = ext.CP() \
.add_policy([2, 23, 140, 1, 2, 1]) \
.add_policy_cps([2, 23, 140, 1, 2, 2], "https://example.com/cps") \
.build()Trait Implementations
Sourceimpl<'py> IntoPyObject<'py> for PyCertificatePoliciesBuilder
impl<'py> IntoPyObject<'py> for PyCertificatePoliciesBuilder
Sourcetype Target = PyCertificatePoliciesBuilder
type Target = PyCertificatePoliciesBuilder
The Python output type
Sourcetype Output = Bound<'py, <PyCertificatePoliciesBuilder as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyCertificatePoliciesBuilder as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClassImpl for PyCertificatePoliciesBuilder
impl PyClassImpl for PyCertificatePoliciesBuilder
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Fluent builder for a ``CertificatePolicies`` extension value (OID 2.5.29.32,
/// RFC 5280 4.2.1.4).
///
/// Add policy entries with optional CPS URI qualifiers using the fluent methods,
/// then call :meth:`build` to obtain the DER bytes of the
/// ``CertificatePolicies`` SEQUENCE OF — the content that goes inside the OCTET
/// STRING wrapper in the ``Extension`` SEQUENCE.
///
/// The class is also available as the short alias ``synta.ext.CP``.
///
/// ```python,ignore
/// import synta.ext as ext
///
/// cp = ext.CP() \
/// .add_policy([2, 23, 140, 1, 2, 1]) \
/// .add_policy_cps([2, 23, 140, 1, 2, 2], "https://example.com/cps") \
/// .build()
/// ```
const RAW_DOC: &'static CStr = /// Fluent builder for a ``CertificatePolicies`` extension value (OID 2.5.29.32, /// RFC 5280 4.2.1.4). /// /// Add policy entries with optional CPS URI qualifiers using the fluent methods, /// then call :meth:`build` to obtain the DER bytes of the /// ``CertificatePolicies`` SEQUENCE OF — the content that goes inside the OCTET /// STRING wrapper in the ``Extension`` SEQUENCE. /// /// The class is also available as the short alias ``synta.ext.CP``. /// /// ```python,ignore /// import synta.ext as ext /// /// cp = ext.CP() \ /// .add_policy([2, 23, 140, 1, 2, 1]) \ /// .add_policy_cps([2, 23, 140, 1, 2, 2], "https://example.com/cps") \ /// .build() /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyCertificatePoliciesBuilder>
type ThreadChecker = SendablePyClass<PyCertificatePoliciesBuilder>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for PyCertificatePoliciesBuilder
impl PyClassNewTextSignature for PyCertificatePoliciesBuilder
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<PyCertificatePoliciesBuilder> for PyClassImplCollector<PyCertificatePoliciesBuilder>
impl PyMethods<PyCertificatePoliciesBuilder> for PyClassImplCollector<PyCertificatePoliciesBuilder>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyCertificatePoliciesBuilder
impl PyTypeInfo for PyCertificatePoliciesBuilder
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
impl DerefToPyAny for PyCertificatePoliciesBuilder
impl ExtractPyClassWithClone for PyCertificatePoliciesBuilder