pub struct PyExtendedKeyUsageBuilder { /* private fields */ }Expand description
Fluent builder for an ExtKeyUsageSyntax extension value
(OID 2.5.29.37, Extended Key Usage, RFC 5280 4.2.1.12).
Add well-known key purpose OIDs with the convenience methods or custom OIDs
via :meth:add_oid, then call :meth:build to obtain the DER bytes of the
ExtKeyUsageSyntax SEQUENCE.
The class is also available as the short alias synta.ext.EKU.
import synta.ext as ext
# Typical TLS server certificate EKU
eku = ext.EKU().server_auth().client_auth().build()
# Custom OID
eku = ext.EKU().add_oid([1, 3, 6, 1, 5, 5, 7, 3, 1]).build()Trait Implementations
impl DerefToPyAny for PyExtendedKeyUsageBuilder
impl ExtractPyClassWithClone for PyExtendedKeyUsageBuilder
Sourceimpl<'py> IntoPyObject<'py> for PyExtendedKeyUsageBuilder
impl<'py> IntoPyObject<'py> for PyExtendedKeyUsageBuilder
Sourcetype Target = PyExtendedKeyUsageBuilder
type Target = PyExtendedKeyUsageBuilder
The Python output type
Sourcetype Output = Bound<'py, <PyExtendedKeyUsageBuilder as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyExtendedKeyUsageBuilder as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyExtendedKeyUsageBuilder
impl PyClass for PyExtendedKeyUsageBuilder
Sourceimpl PyClassImpl for PyExtendedKeyUsageBuilder
impl PyClassImpl for PyExtendedKeyUsageBuilder
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Fluent builder for an ``ExtKeyUsageSyntax`` extension value
/// (OID 2.5.29.37, Extended Key Usage, RFC 5280 4.2.1.12).
///
/// Add well-known key purpose OIDs with the convenience methods or custom OIDs
/// via :meth:`add_oid`, then call :meth:`build` to obtain the DER bytes of the
/// ``ExtKeyUsageSyntax`` SEQUENCE.
///
/// The class is also available as the short alias ``synta.ext.EKU``.
///
/// ```python,ignore
/// import synta.ext as ext
///
/// # Typical TLS server certificate EKU
/// eku = ext.EKU().server_auth().client_auth().build()
///
/// # Custom OID
/// eku = ext.EKU().add_oid([1, 3, 6, 1, 5, 5, 7, 3, 1]).build()
/// ```
const RAW_DOC: &'static CStr = /// Fluent builder for an ``ExtKeyUsageSyntax`` extension value /// (OID 2.5.29.37, Extended Key Usage, RFC 5280 4.2.1.12). /// /// Add well-known key purpose OIDs with the convenience methods or custom OIDs /// via :meth:`add_oid`, then call :meth:`build` to obtain the DER bytes of the /// ``ExtKeyUsageSyntax`` SEQUENCE. /// /// The class is also available as the short alias ``synta.ext.EKU``. /// /// ```python,ignore /// import synta.ext as ext /// /// # Typical TLS server certificate EKU /// eku = ext.EKU().server_auth().client_auth().build() /// /// # Custom OID /// eku = ext.EKU().add_oid([1, 3, 6, 1, 5, 5, 7, 3, 1]).build() /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyExtendedKeyUsageBuilder>
type ThreadChecker = SendablePyClass<PyExtendedKeyUsageBuilder>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for PyExtendedKeyUsageBuilder
impl PyClassNewTextSignature for PyExtendedKeyUsageBuilder
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<PyExtendedKeyUsageBuilder> for PyClassImplCollector<PyExtendedKeyUsageBuilder>
impl PyMethods<PyExtendedKeyUsageBuilder> for PyClassImplCollector<PyExtendedKeyUsageBuilder>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyExtendedKeyUsageBuilder
impl PyTypeInfo for PyExtendedKeyUsageBuilder
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.