PyIssuerAlternativeNameBuilder

Struct PyIssuerAlternativeNameBuilder 

pub struct PyIssuerAlternativeNameBuilder { /* private fields */ }
Fluent builder for an IssuerAltName extension value (OID 2.5.29.18).

Accumulate :class:GeneralName entries with the fluent methods, then call :meth:build to obtain the DER bytes of the GeneralNames SEQUENCE — the content that goes inside the OCTET STRING wrapper in the Extension SEQUENCE.

The encoding is identical to :class:SubjectAlternativeNameBuilder (OID 2.5.29.17) but uses the Issuer Alternative Name OID (2.5.29.18) instead. Note: otherName is not supported by this builder.

The class is also available as the short alias synta.ext.IAN.

import synta.ext as ext

ian = ext.IAN() \
    .rfc822_name("ca@example.com") \
    .uri("http://www.example.com") \
    .build()