pub struct PyIssuingDistributionPointBuilder { /* private fields */ }Expand description
Fluent builder for an IssuingDistributionPoint extension value
(OID 2.5.29.28, RFC 5280 5.2.5).
The IssuingDistributionPoint extension identifies the CRL distribution
point and scope for a particular CRL. Configure the distribution point and
the boolean flags with the fluent methods, then call :meth:build to obtain
the DER bytes — the content that goes inside the OCTET STRING wrapper in the
Extension SEQUENCE.
The class is also available as the short alias synta.ext.IDP.
import synta.ext as ext
idp = ext.IDP() \
.full_name_uri("http://crl.example.com/ca.crl") \
.only_contains_user_certs(True) \
.build()Trait Implementations
impl DerefToPyAny for PyIssuingDistributionPointBuilder
impl ExtractPyClassWithClone for PyIssuingDistributionPointBuilder
Sourceimpl<'py> IntoPyObject<'py> for PyIssuingDistributionPointBuilder
impl<'py> IntoPyObject<'py> for PyIssuingDistributionPointBuilder
Sourcetype Target = PyIssuingDistributionPointBuilder
type Target = PyIssuingDistributionPointBuilder
The Python output type
Sourcetype Output = Bound<'py, <PyIssuingDistributionPointBuilder as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyIssuingDistributionPointBuilder as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClassImpl for PyIssuingDistributionPointBuilder
impl PyClassImpl for PyIssuingDistributionPointBuilder
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Fluent builder for an ``IssuingDistributionPoint`` extension value
/// (OID 2.5.29.28, RFC 5280 5.2.5).
///
/// The ``IssuingDistributionPoint`` extension identifies the CRL distribution
/// point and scope for a particular CRL. Configure the distribution point and
/// the boolean flags with the fluent methods, then call :meth:`build` to obtain
/// the DER bytes — the content that goes inside the OCTET STRING wrapper in the
/// ``Extension`` SEQUENCE.
///
/// The class is also available as the short alias ``synta.ext.IDP``.
///
/// ```python,ignore
/// import synta.ext as ext
///
/// idp = ext.IDP() \
/// .full_name_uri("http://crl.example.com/ca.crl") \
/// .only_contains_user_certs(True) \
/// .build()
/// ```
const RAW_DOC: &'static CStr = /// Fluent builder for an ``IssuingDistributionPoint`` extension value /// (OID 2.5.29.28, RFC 5280 5.2.5). /// /// The ``IssuingDistributionPoint`` extension identifies the CRL distribution /// point and scope for a particular CRL. Configure the distribution point and /// the boolean flags with the fluent methods, then call :meth:`build` to obtain /// the DER bytes — the content that goes inside the OCTET STRING wrapper in the /// ``Extension`` SEQUENCE. /// /// The class is also available as the short alias ``synta.ext.IDP``. /// /// ```python,ignore /// import synta.ext as ext /// /// idp = ext.IDP() \ /// .full_name_uri("http://crl.example.com/ca.crl") \ /// .only_contains_user_certs(True) \ /// .build() /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyIssuingDistributionPointBuilder>
type ThreadChecker = SendablePyClass<PyIssuingDistributionPointBuilder>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for PyIssuingDistributionPointBuilder
impl PyClassNewTextSignature for PyIssuingDistributionPointBuilder
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<PyIssuingDistributionPointBuilder> for PyClassImplCollector<PyIssuingDistributionPointBuilder>
impl PyMethods<PyIssuingDistributionPointBuilder> for PyClassImplCollector<PyIssuingDistributionPointBuilder>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyIssuingDistributionPointBuilder
impl PyTypeInfo for PyIssuingDistributionPointBuilder
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.