pub struct PySubjectAlternativeNameBuilder { /* private fields */ }Expand description
Fluent builder for a SubjectAltName extension value (OID 2.5.29.17).
Accumulate :class:GeneralName entries with the fluent methods, then call
:meth:build to obtain the DER bytes of the GeneralNames SEQUENCE —
the content that goes inside the OCTET STRING wrapper in the Extension
SEQUENCE.
The class is also available as the short alias synta.ext.SAN.
import synta.ext as ext
san = ext.SAN() \
.dns_name("www.example.com") \
.dns_name("example.com") \
.rfc822_name("admin@example.com") \
.ip_address(b"\xc0\xa8\x01\x01") \
.build()Trait Implementations
Sourceimpl<'py> IntoPyObject<'py> for PySubjectAlternativeNameBuilder
impl<'py> IntoPyObject<'py> for PySubjectAlternativeNameBuilder
Sourcetype Target = PySubjectAlternativeNameBuilder
type Target = PySubjectAlternativeNameBuilder
The Python output type
Sourcetype Output = Bound<'py, <PySubjectAlternativeNameBuilder as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PySubjectAlternativeNameBuilder as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClassImpl for PySubjectAlternativeNameBuilder
impl PyClassImpl for PySubjectAlternativeNameBuilder
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Fluent builder for a ``SubjectAltName`` extension value (OID 2.5.29.17).
///
/// Accumulate :class:`GeneralName` entries with the fluent methods, then call
/// :meth:`build` to obtain the DER bytes of the ``GeneralNames`` SEQUENCE —
/// the content that goes inside the OCTET STRING wrapper in the ``Extension``
/// SEQUENCE.
///
/// The class is also available as the short alias ``synta.ext.SAN``.
///
/// ```python,ignore
/// import synta.ext as ext
///
/// san = ext.SAN() \
/// .dns_name("www.example.com") \
/// .dns_name("example.com") \
/// .rfc822_name("admin@example.com") \
/// .ip_address(b"\xc0\xa8\x01\x01") \
/// .build()
/// ```
const RAW_DOC: &'static CStr = /// Fluent builder for a ``SubjectAltName`` extension value (OID 2.5.29.17). /// /// Accumulate :class:`GeneralName` entries with the fluent methods, then call /// :meth:`build` to obtain the DER bytes of the ``GeneralNames`` SEQUENCE — /// the content that goes inside the OCTET STRING wrapper in the ``Extension`` /// SEQUENCE. /// /// The class is also available as the short alias ``synta.ext.SAN``. /// /// ```python,ignore /// import synta.ext as ext /// /// san = ext.SAN() \ /// .dns_name("www.example.com") \ /// .dns_name("example.com") \ /// .rfc822_name("admin@example.com") \ /// .ip_address(b"\xc0\xa8\x01\x01") \ /// .build() /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PySubjectAlternativeNameBuilder>
type ThreadChecker = SendablePyClass<PySubjectAlternativeNameBuilder>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for PySubjectAlternativeNameBuilder
impl PyClassNewTextSignature for PySubjectAlternativeNameBuilder
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<PySubjectAlternativeNameBuilder> for PyClassImplCollector<PySubjectAlternativeNameBuilder>
impl PyMethods<PySubjectAlternativeNameBuilder> for PyClassImplCollector<PySubjectAlternativeNameBuilder>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PySubjectAlternativeNameBuilder
impl PyTypeInfo for PySubjectAlternativeNameBuilder
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
impl DerefToPyAny for PySubjectAlternativeNameBuilder
impl ExtractPyClassWithClone for PySubjectAlternativeNameBuilder