pub struct PyTOTP { /* private fields */ }Expand description
Time-based One-Time Password generator (RFC 6238).
The counter is derived from the Unix timestamp divided by the time step
(period seconds, default 30). Supports HMAC-SHA1, HMAC-SHA256,
HMAC-SHA384, and HMAC-SHA512.
import synta.crypto, time
key = bytes.fromhex("3132333435363738393031323334353637383930")
totp = synta.crypto.TOTP(key, digits=8, algorithm="sha1", period=30)
otp = totp.now() # current time step
otp = totp.generate(int(time.time())) # explicit Unix timestampTrait Implementations
impl DerefToPyAny for PyTOTP
impl ExtractPyClassWithClone for PyTOTP
Sourceimpl<'py> IntoPyObject<'py> for PyTOTP
impl<'py> IntoPyObject<'py> for PyTOTP
Sourcetype Output = Bound<'py, <PyTOTP as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyTOTP as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClassImpl for PyTOTP
impl PyClassImpl for PyTOTP
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Time-based One-Time Password generator (RFC 6238).
///
/// The counter is derived from the Unix timestamp divided by the time step
/// (``period`` seconds, default 30). Supports HMAC-SHA1, HMAC-SHA256,
/// HMAC-SHA384, and HMAC-SHA512.
///
/// ```python,ignore
/// import synta.crypto, time
///
/// key = bytes.fromhex("3132333435363738393031323334353637383930")
/// totp = synta.crypto.TOTP(key, digits=8, algorithm="sha1", period=30)
/// otp = totp.now() # current time step
/// otp = totp.generate(int(time.time())) # explicit Unix timestamp
/// ```
const RAW_DOC: &'static CStr = /// Time-based One-Time Password generator (RFC 6238). /// /// The counter is derived from the Unix timestamp divided by the time step /// (``period`` seconds, default 30). Supports HMAC-SHA1, HMAC-SHA256, /// HMAC-SHA384, and HMAC-SHA512. /// /// ```python,ignore /// import synta.crypto, time /// /// key = bytes.fromhex("3132333435363738393031323334353637383930") /// totp = synta.crypto.TOTP(key, digits=8, algorithm="sha1", period=30) /// otp = totp.now() # current time step /// otp = totp.generate(int(time.time())) # explicit Unix timestamp /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyTOTP>
type ThreadChecker = SendablePyClass<PyTOTP>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for PyTOTP
impl PyClassNewTextSignature for PyTOTP
const TEXT_SIGNATURE: &'static str = "(key, digits=6, algorithm=\"sha1\", period=30)"
Sourceimpl PyMethods<PyTOTP> for PyClassImplCollector<PyTOTP>
impl PyMethods<PyTOTP> for PyClassImplCollector<PyTOTP>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyTOTP
impl PyTypeInfo for PyTOTP
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.