Module pkcs11

Module pkcs11 

Python bindings for PKCS#11 token management.

Exposes the synta.pkcs11 submodule with:

  • SlotInfo — information about a PKCS#11 slot / token
  • KeyInfo — information about a private key stored on a token
  • Pkcs11Token — session handle for a single named token
  • list_slots(module=None) — enumerate all token slots

Structs

PyKeyInfo
Information about a private key object stored on a PKCS#11 token.
PyPkcs11Token
A handle for PKCS#11 management operations on a single named token.
PySlotInfo
Information about a PKCS#11 token slot.

Functions

list_slots
List all PKCS#11 token slots using the system module.
register_pkcs11_module