pub struct PyChecksum { /* private fields */ }Expand description
Kerberos Checksum — RFC 3961 4 / RFC 4556
Contains the checksum algorithm type identifier and the raw checksum value.
ck = synta.krb5.Checksum.from_der(der_bytes)
print(ck.cksumtype, ck.checksum.hex())Trait Implementations
Sourceimpl<'py> IntoPyObject<'py> for PyChecksum
impl<'py> IntoPyObject<'py> for PyChecksum
Sourcetype Target = PyChecksum
type Target = PyChecksum
The Python output type
Sourcetype Output = Bound<'py, <PyChecksum as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyChecksum as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClassImpl for PyChecksum
impl PyClassImpl for PyChecksum
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Kerberos Checksum — RFC 3961 4 / RFC 4556
///
/// Contains the checksum algorithm type identifier and the raw checksum value.
///
/// ```python
/// ck = synta.krb5.Checksum.from_der(der_bytes)
/// print(ck.cksumtype, ck.checksum.hex())
/// ```
const RAW_DOC: &'static CStr = /// Kerberos Checksum — RFC 3961 4 / RFC 4556 /// /// Contains the checksum algorithm type identifier and the raw checksum value. /// /// ```python /// ck = synta.krb5.Checksum.from_der(der_bytes) /// print(ck.cksumtype, ck.checksum.hex()) /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyChecksum>
type ThreadChecker = SendablePyClass<PyChecksum>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyMethods<PyChecksum> for PyClassImplCollector<PyChecksum>
impl PyMethods<PyChecksum> for PyClassImplCollector<PyChecksum>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyChecksum
impl PyTypeInfo for PyChecksum
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
impl DerefToPyAny for PyChecksum
impl ExtractPyClassWithClone for PyChecksum