pub struct PyPaPkAsReq { /* private fields */ }Expand description
PKINIT PA-PK-AS-REQ — RFC 4556 3.2.2
Pre-authentication data sent by the client in the initial AS-REQ.
req = synta.krb5.PaPkAsReq.from_der(der_bytes)
print(len(req.signed_auth_pack))Trait Implementations
Sourceimpl<'py> IntoPyObject<'py> for PyPaPkAsReq
impl<'py> IntoPyObject<'py> for PyPaPkAsReq
Sourcetype Target = PyPaPkAsReq
type Target = PyPaPkAsReq
The Python output type
Sourcetype Output = Bound<'py, <PyPaPkAsReq as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyPaPkAsReq as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyPaPkAsReq
impl PyClass for PyPaPkAsReq
Sourceimpl PyClassImpl for PyPaPkAsReq
impl PyClassImpl for PyPaPkAsReq
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// PKINIT PA-PK-AS-REQ — RFC 4556 3.2.2
///
/// Pre-authentication data sent by the client in the initial AS-REQ.
///
/// ```python
/// req = synta.krb5.PaPkAsReq.from_der(der_bytes)
/// print(len(req.signed_auth_pack))
/// ```
const RAW_DOC: &'static CStr = /// PKINIT PA-PK-AS-REQ — RFC 4556 3.2.2 /// /// Pre-authentication data sent by the client in the initial AS-REQ. /// /// ```python /// req = synta.krb5.PaPkAsReq.from_der(der_bytes) /// print(len(req.signed_auth_pack)) /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyPaPkAsReq>
type ThreadChecker = SendablePyClass<PyPaPkAsReq>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyMethods<PyPaPkAsReq> for PyClassImplCollector<PyPaPkAsReq>
impl PyMethods<PyPaPkAsReq> for PyClassImplCollector<PyPaPkAsReq>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyPaPkAsReq
impl PyTypeInfo for PyPaPkAsReq
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
impl DerefToPyAny for PyPaPkAsReq
impl ExtractPyClassWithClone for PyPaPkAsReq