pub struct PyReplyKeyPack { /* private fields */ }Expand description
PKINIT ReplyKeyPack — RFC 4556 3.2.3
The session key and checksum sent by the KDC to an authenticated client.
pack = synta.krb5.ReplyKeyPack.from_der(der_bytes)
print(pack.reply_key.keytype)Trait Implementations
Sourceimpl<'py> IntoPyObject<'py> for PyReplyKeyPack
impl<'py> IntoPyObject<'py> for PyReplyKeyPack
Sourcetype Target = PyReplyKeyPack
type Target = PyReplyKeyPack
The Python output type
Sourcetype Output = Bound<'py, <PyReplyKeyPack as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyReplyKeyPack as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyReplyKeyPack
impl PyClass for PyReplyKeyPack
Sourceimpl PyClassImpl for PyReplyKeyPack
impl PyClassImpl for PyReplyKeyPack
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// PKINIT ReplyKeyPack — RFC 4556 3.2.3
///
/// The session key and checksum sent by the KDC to an authenticated client.
///
/// ```python
/// pack = synta.krb5.ReplyKeyPack.from_der(der_bytes)
/// print(pack.reply_key.keytype)
/// ```
const RAW_DOC: &'static CStr = /// PKINIT ReplyKeyPack — RFC 4556 3.2.3 /// /// The session key and checksum sent by the KDC to an authenticated client. /// /// ```python /// pack = synta.krb5.ReplyKeyPack.from_der(der_bytes) /// print(pack.reply_key.keytype) /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyReplyKeyPack>
type ThreadChecker = SendablePyClass<PyReplyKeyPack>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyMethods<PyReplyKeyPack> for PyClassImplCollector<PyReplyKeyPack>
impl PyMethods<PyReplyKeyPack> for PyClassImplCollector<PyReplyKeyPack>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyReplyKeyPack
impl PyTypeInfo for PyReplyKeyPack
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
impl DerefToPyAny for PyReplyKeyPack
impl ExtractPyClassWithClone for PyReplyKeyPack