pub struct PyCertificateBuilder { /* private fields */ }Expand description
Builder for X.509 v3 certificates.
All Name, SubjectPublicKeyInfo, and extension-value bytes are stored as-is and spliced verbatim into the TBS DER at signing time — no re-parse or re-encode. The only allocation per field is the initial copy of the byte slice into the builder’s owned storage.
Each setter method returns the same builder object, so calls can be
chained with .:
import synta, datetime
now = datetime.datetime(2024, 1, 1, tzinfo=datetime.timezone.utc)
then = datetime.datetime(2025, 1, 1, tzinfo=datetime.timezone.utc)
cert = (
synta.CertificateBuilder()
.issuer_name(ca_cert.subject_raw_der)
.subject_name(csr.subject_raw_der)
.public_key_der(csr.subject_public_key_info_der)
.serial_number(42)
.not_valid_before_utc(now)
.not_valid_after_utc(then)
.add_extension("2.5.29.19", True, bc_der)
.sign(ca_key, "sha256")
)Trait Implementations
impl DerefToPyAny for PyCertificateBuilder
impl ExtractPyClassWithClone for PyCertificateBuilder
Sourceimpl<'py> IntoPyObject<'py> for PyCertificateBuilder
impl<'py> IntoPyObject<'py> for PyCertificateBuilder
Sourcetype Target = PyCertificateBuilder
type Target = PyCertificateBuilder
The Python output type
Sourcetype Output = Bound<'py, <PyCertificateBuilder as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyCertificateBuilder as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyCertificateBuilder
impl PyClass for PyCertificateBuilder
Sourceimpl PyClassImpl for PyCertificateBuilder
impl PyClassImpl for PyCertificateBuilder
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Builder for X.509 v3 certificates.
///
/// All Name, SubjectPublicKeyInfo, and extension-value bytes are stored as-is
/// and spliced verbatim into the TBS DER at signing time — no re-parse or
/// re-encode. The only allocation per field is the initial copy of the byte
/// slice into the builder's owned storage.
///
/// Each setter method returns the **same** builder object, so calls can be
/// chained with ``.``:
///
/// ```python,ignore
/// import synta, datetime
///
/// now = datetime.datetime(2024, 1, 1, tzinfo=datetime.timezone.utc)
/// then = datetime.datetime(2025, 1, 1, tzinfo=datetime.timezone.utc)
///
/// cert = (
/// synta.CertificateBuilder()
/// .issuer_name(ca_cert.subject_raw_der)
/// .subject_name(csr.subject_raw_der)
/// .public_key_der(csr.subject_public_key_info_der)
/// .serial_number(42)
/// .not_valid_before_utc(now)
/// .not_valid_after_utc(then)
/// .add_extension("2.5.29.19", True, bc_der)
/// .sign(ca_key, "sha256")
/// )
/// ```
const RAW_DOC: &'static CStr = /// Builder for X.509 v3 certificates. /// /// All Name, SubjectPublicKeyInfo, and extension-value bytes are stored as-is /// and spliced verbatim into the TBS DER at signing time — no re-parse or /// re-encode. The only allocation per field is the initial copy of the byte /// slice into the builder's owned storage. /// /// Each setter method returns the **same** builder object, so calls can be /// chained with ``.``: /// /// ```python,ignore /// import synta, datetime /// /// now = datetime.datetime(2024, 1, 1, tzinfo=datetime.timezone.utc) /// then = datetime.datetime(2025, 1, 1, tzinfo=datetime.timezone.utc) /// /// cert = ( /// synta.CertificateBuilder() /// .issuer_name(ca_cert.subject_raw_der) /// .subject_name(csr.subject_raw_der) /// .public_key_der(csr.subject_public_key_info_der) /// .serial_number(42) /// .not_valid_before_utc(now) /// .not_valid_after_utc(then) /// .add_extension("2.5.29.19", True, bc_der) /// .sign(ca_key, "sha256") /// ) /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyCertificateBuilder>
type ThreadChecker = SendablePyClass<PyCertificateBuilder>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for PyCertificateBuilder
impl PyClassNewTextSignature for PyCertificateBuilder
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<PyCertificateBuilder> for PyClassImplCollector<PyCertificateBuilder>
impl PyMethods<PyCertificateBuilder> for PyClassImplCollector<PyCertificateBuilder>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyCertificateBuilder
impl PyTypeInfo for PyCertificateBuilder
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.