pub struct PyMlDsaPublicKey { /* private fields */ }Expand description
A validated ML-DSA public key (RFC 9881 / FIPS 204).
ML-DSA public keys are raw byte strings carried in
SubjectPublicKeyInfo.subjectPublicKey (as BIT STRING value bytes, with
the unused-bits prefix stripped). The expected sizes are:
ML_DSA_44— 1312 bytesML_DSA_65— 1952 bytesML_DSA_87— 2592 bytes
Use :meth:from_bytes with the algorithm OID from
SubjectPublicKeyInfo.algorithm to validate and wrap the raw key bytes:
oid = cert.subject_public_key_algorithm
raw = cert.subject_public_key
pub_key = synta.MlDsaPublicKey.from_bytes(oid, raw)Trait Implementations
impl DerefToPyAny for PyMlDsaPublicKey
impl ExtractPyClassWithClone for PyMlDsaPublicKey
Sourceimpl<'py> IntoPyObject<'py> for PyMlDsaPublicKey
impl<'py> IntoPyObject<'py> for PyMlDsaPublicKey
Sourcetype Target = PyMlDsaPublicKey
type Target = PyMlDsaPublicKey
The Python output type
Sourcetype Output = Bound<'py, <PyMlDsaPublicKey as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyMlDsaPublicKey as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyMlDsaPublicKey
impl PyClass for PyMlDsaPublicKey
Sourceimpl PyClassImpl for PyMlDsaPublicKey
impl PyClassImpl for PyMlDsaPublicKey
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// A validated ML-DSA public key (RFC 9881 / FIPS 204).
///
/// ML-DSA public keys are raw byte strings carried in
/// ``SubjectPublicKeyInfo.subjectPublicKey`` (as BIT STRING value bytes, with
/// the unused-bits prefix stripped). The expected sizes are:
///
/// - ``ML_DSA_44`` — 1312 bytes
/// - ``ML_DSA_65`` — 1952 bytes
/// - ``ML_DSA_87`` — 2592 bytes
///
/// Use :meth:`from_bytes` with the algorithm OID from
/// ``SubjectPublicKeyInfo.algorithm`` to validate and wrap the raw key bytes:
///
/// ```python,ignore
/// oid = cert.subject_public_key_algorithm
/// raw = cert.subject_public_key
/// pub_key = synta.MlDsaPublicKey.from_bytes(oid, raw)
/// ```
const RAW_DOC: &'static CStr = /// A validated ML-DSA public key (RFC 9881 / FIPS 204). /// /// ML-DSA public keys are raw byte strings carried in /// ``SubjectPublicKeyInfo.subjectPublicKey`` (as BIT STRING value bytes, with /// the unused-bits prefix stripped). The expected sizes are: /// /// - ``ML_DSA_44`` — 1312 bytes /// - ``ML_DSA_65`` — 1952 bytes /// - ``ML_DSA_87`` — 2592 bytes /// /// Use :meth:`from_bytes` with the algorithm OID from /// ``SubjectPublicKeyInfo.algorithm`` to validate and wrap the raw key bytes: /// /// ```python,ignore /// oid = cert.subject_public_key_algorithm /// raw = cert.subject_public_key /// pub_key = synta.MlDsaPublicKey.from_bytes(oid, raw) /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyMlDsaPublicKey>
type ThreadChecker = SendablePyClass<PyMlDsaPublicKey>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyMethods<PyMlDsaPublicKey> for PyClassImplCollector<PyMlDsaPublicKey>
impl PyMethods<PyMlDsaPublicKey> for PyClassImplCollector<PyMlDsaPublicKey>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyMlDsaPublicKey
impl PyTypeInfo for PyMlDsaPublicKey
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.