pub struct PyLogotypeExtnBuilder { /* private fields */ }Expand description
Python-facing wrapper for synta_certificate::LogotypeExtnBuilder.
Builds a DER-encoded LogotypeExtn SEQUENCE (RFC 9399).
The extension value goes inside the OCTET STRING wrapper of an X.509
Extension SEQUENCE for OID 1.3.6.1.5.5.7.1.12.
At least one of communityLogos, issuerLogo, subjectLogo, or
otherLogos must be set before calling :meth:build.
Each logo is described by four parameters passed as keyword arguments or positional values to the setter methods:
media_type— MIME type string, e.g."image/png"hash_alg_oid— hash algorithm OID as a list of arc integers, e.g.list(synta.oids.SHA256.components())hash_value— raw hash bytes of the logotype objecturi— URI from which the logotype can be retrieved
Example::
import hashlib, synta
img_hash = hashlib.sha256(open("logo.png", "rb").read()).digest()
sha256_comps = list(synta.oids.SHA256.components())
extn_der = (
synta.LogotypeExtnBuilder()
.subject_logo_direct(
media_type="image/png",
hash_alg_oid=sha256_comps,
hash_value=img_hash,
uri="https://www.example.com/logo.png",
)
.build()
)Trait Implementations
impl DerefToPyAny for PyLogotypeExtnBuilder
impl ExtractPyClassWithClone for PyLogotypeExtnBuilder
Sourceimpl<'py> IntoPyObject<'py> for PyLogotypeExtnBuilder
impl<'py> IntoPyObject<'py> for PyLogotypeExtnBuilder
Sourcetype Target = PyLogotypeExtnBuilder
type Target = PyLogotypeExtnBuilder
The Python output type
Sourcetype Output = Bound<'py, <PyLogotypeExtnBuilder as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyLogotypeExtnBuilder as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyLogotypeExtnBuilder
impl PyClass for PyLogotypeExtnBuilder
Sourceimpl PyClassImpl for PyLogotypeExtnBuilder
impl PyClassImpl for PyLogotypeExtnBuilder
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Python-facing wrapper for [`synta_certificate::LogotypeExtnBuilder`].
///
/// Builds a DER-encoded ``LogotypeExtn`` SEQUENCE (RFC 9399).
///
/// The extension value goes inside the OCTET STRING wrapper of an X.509
/// ``Extension`` SEQUENCE for OID ``1.3.6.1.5.5.7.1.12``.
///
/// At least one of ``communityLogos``, ``issuerLogo``, ``subjectLogo``, or
/// ``otherLogos`` must be set before calling :meth:`build`.
///
/// Each logo is described by four parameters passed as keyword arguments or
/// positional values to the setter methods:
///
/// - ``media_type`` — MIME type string, e.g. ``"image/png"``
/// - ``hash_alg_oid`` — hash algorithm OID as a list of arc integers,
/// e.g. ``list(synta.oids.SHA256.components())``
/// - ``hash_value`` — raw hash bytes of the logotype object
/// - ``uri`` — URI from which the logotype can be retrieved
///
/// Example::
///
/// import hashlib, synta
///
/// img_hash = hashlib.sha256(open("logo.png", "rb").read()).digest()
/// sha256_comps = list(synta.oids.SHA256.components())
///
/// extn_der = (
/// synta.LogotypeExtnBuilder()
/// .subject_logo_direct(
/// media_type="image/png",
/// hash_alg_oid=sha256_comps,
/// hash_value=img_hash,
/// uri="https://www.example.com/logo.png",
/// )
/// .build()
/// )
const RAW_DOC: &'static CStr = /// Python-facing wrapper for [`synta_certificate::LogotypeExtnBuilder`]. /// /// Builds a DER-encoded ``LogotypeExtn`` SEQUENCE (RFC 9399). /// /// The extension value goes inside the OCTET STRING wrapper of an X.509 /// ``Extension`` SEQUENCE for OID ``1.3.6.1.5.5.7.1.12``. /// /// At least one of ``communityLogos``, ``issuerLogo``, ``subjectLogo``, or /// ``otherLogos`` must be set before calling :meth:`build`. /// /// Each logo is described by four parameters passed as keyword arguments or /// positional values to the setter methods: /// /// - ``media_type`` — MIME type string, e.g. ``"image/png"`` /// - ``hash_alg_oid`` — hash algorithm OID as a list of arc integers, /// e.g. ``list(synta.oids.SHA256.components())`` /// - ``hash_value`` — raw hash bytes of the logotype object /// - ``uri`` — URI from which the logotype can be retrieved /// /// Example:: /// /// import hashlib, synta /// /// img_hash = hashlib.sha256(open("logo.png", "rb").read()).digest() /// sha256_comps = list(synta.oids.SHA256.components()) /// /// extn_der = ( /// synta.LogotypeExtnBuilder() /// .subject_logo_direct( /// media_type="image/png", /// hash_alg_oid=sha256_comps, /// hash_value=img_hash, /// uri="https://www.example.com/logo.png", /// ) /// .build() /// )
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyLogotypeExtnBuilder>
type ThreadChecker = SendablePyClass<PyLogotypeExtnBuilder>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for PyLogotypeExtnBuilder
impl PyClassNewTextSignature for PyLogotypeExtnBuilder
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<PyLogotypeExtnBuilder> for PyClassImplCollector<PyLogotypeExtnBuilder>
impl PyMethods<PyLogotypeExtnBuilder> for PyClassImplCollector<PyLogotypeExtnBuilder>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyLogotypeExtnBuilder
impl PyTypeInfo for PyLogotypeExtnBuilder
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.