pub struct PyIssuerAlternativeNameBuilder { /* private fields */ }Expand description
Fluent builder for an IssuerAltName extension value (OID 2.5.29.18).
Accumulate :class:GeneralName entries with the fluent methods, then call
:meth:build to obtain the DER bytes of the GeneralNames SEQUENCE —
the content that goes inside the OCTET STRING wrapper in the Extension
SEQUENCE.
The encoding is identical to :class:SubjectAlternativeNameBuilder (OID
2.5.29.17) but uses the Issuer Alternative Name OID (2.5.29.18) instead.
Note: otherName is not supported by this builder.
The class is also available as the short alias synta.ext.IAN.
import synta.ext as ext
ian = ext.IAN() \
.rfc822_name("ca@example.com") \
.uri("http://www.example.com") \
.build()Trait Implementations
impl DerefToPyAny for PyIssuerAlternativeNameBuilder
impl ExtractPyClassWithClone for PyIssuerAlternativeNameBuilder
Sourceimpl<'py> IntoPyObject<'py> for PyIssuerAlternativeNameBuilder
impl<'py> IntoPyObject<'py> for PyIssuerAlternativeNameBuilder
Sourcetype Target = PyIssuerAlternativeNameBuilder
type Target = PyIssuerAlternativeNameBuilder
The Python output type
Sourcetype Output = Bound<'py, <PyIssuerAlternativeNameBuilder as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyIssuerAlternativeNameBuilder as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClassImpl for PyIssuerAlternativeNameBuilder
impl PyClassImpl for PyIssuerAlternativeNameBuilder
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Fluent builder for an ``IssuerAltName`` extension value (OID 2.5.29.18).
///
/// Accumulate :class:`GeneralName` entries with the fluent methods, then call
/// :meth:`build` to obtain the DER bytes of the ``GeneralNames`` SEQUENCE —
/// the content that goes inside the OCTET STRING wrapper in the ``Extension``
/// SEQUENCE.
///
/// The encoding is identical to :class:`SubjectAlternativeNameBuilder` (OID
/// 2.5.29.17) but uses the Issuer Alternative Name OID (2.5.29.18) instead.
/// Note: ``otherName`` is not supported by this builder.
///
/// The class is also available as the short alias ``synta.ext.IAN``.
///
/// ```python,ignore
/// import synta.ext as ext
///
/// ian = ext.IAN() \
/// .rfc822_name("ca@example.com") \
/// .uri("http://www.example.com") \
/// .build()
/// ```
const RAW_DOC: &'static CStr = /// Fluent builder for an ``IssuerAltName`` extension value (OID 2.5.29.18). /// /// Accumulate :class:`GeneralName` entries with the fluent methods, then call /// :meth:`build` to obtain the DER bytes of the ``GeneralNames`` SEQUENCE — /// the content that goes inside the OCTET STRING wrapper in the ``Extension`` /// SEQUENCE. /// /// The encoding is identical to :class:`SubjectAlternativeNameBuilder` (OID /// 2.5.29.17) but uses the Issuer Alternative Name OID (2.5.29.18) instead. /// Note: ``otherName`` is not supported by this builder. /// /// The class is also available as the short alias ``synta.ext.IAN``. /// /// ```python,ignore /// import synta.ext as ext /// /// ian = ext.IAN() \ /// .rfc822_name("ca@example.com") \ /// .uri("http://www.example.com") \ /// .build() /// ```
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyIssuerAlternativeNameBuilder>
type ThreadChecker = SendablePyClass<PyIssuerAlternativeNameBuilder>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for PyIssuerAlternativeNameBuilder
impl PyClassNewTextSignature for PyIssuerAlternativeNameBuilder
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<PyIssuerAlternativeNameBuilder> for PyClassImplCollector<PyIssuerAlternativeNameBuilder>
impl PyMethods<PyIssuerAlternativeNameBuilder> for PyClassImplCollector<PyIssuerAlternativeNameBuilder>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for PyIssuerAlternativeNameBuilder
impl PyTypeInfo for PyIssuerAlternativeNameBuilder
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.