Python bindings for PKCS#11 token management.
Exposes the synta.pkcs11 submodule with:
SlotInfo— information about a PKCS#11 slot / tokenKeyInfo— information about a private key stored on a tokenPkcs11Token— session handle for a single named tokenlist_slots(module=None)— enumerate all token slots
Structs
- PyKey
Info - Information about a private key object stored on a PKCS#11 token.
- PyPkcs11
Token - A handle for PKCS#11 management operations on a single named token.
- PySlot
Info - Information about a PKCS#11 token slot.
Functions
- list_
slots - List all PKCS#11 token slots using the system module.
- register_
pkcs11_ module